import 'dart:async';
import 'dart:math';

import 'package:flutter/material.dart';
import 'package:vtmap_gl/vtmap_gl.dart';
import 'main.dart';
import 'page.dart';
import 'package:fluttertoast/fluttertoast.dart';

class FullMapPage extends ExamplePage {
  FullMapPage() : super(const Icon(Icons.map), 'Full screen map');

  @override
  Widget build(BuildContext context) {
    return const FullMap();
  }
}

class FullMap extends StatefulWidget {
  const FullMap();

  @override
  State createState() => FullMapState();
}

class FullMapState extends State<FullMap> {
  MapboxMapController mapController;
  bool setStyle = false;

  void _onMapCreated(MapboxMapController controller) {
    mapController = controller;
  }

  void _onCameraMovingStarted() {
    //print('------------------- _onCameraMovingStarted');
  }
  void _onCameraIdle() {
    // print('------------------- _onCameraIdle');
    // print(mapController.cameraPosition.target.latitude);
    // print(mapController.cameraPosition.target.longitude);
  }

  void _onStyleLoadedCallback() {
    var wayPoints = List<WayPoint>();
    final _origin =
        WayPoint(name: "origin", latitude: 16.060476, longitude: 108.215501);

    // final _stop2 = WayPoint(
    //     name: "wp2", latitude:  16.064367555809767, longitude: 108.21520834606599);

    // final _stop3 = WayPoint(
    // name: "Way Point 23", latitude: 16.060947115368748, longitude: 108.21963504690751);

    final _stop1 =
        WayPoint(name: "dest", latitude: 16.066665, longitude: 108.210938);

    wayPoints.add(_origin);
    //  wayPoints.add(_stop2);
    //   wayPoints.add(_stop3);
    wayPoints.add(_stop1);

    VTMapOptions option = VTMapOptions(
        alternatives: true, padding: EdgeInsets.only(top: 10, bottom: 200));

    mapController.buildRoute(wayPoints: wayPoints, options: option);
    print("--------------------------");
    print(setStyle);
    if (!setStyle) {
      setStyle = true;
      //mapController.setStyle(
      //    'https://api.viettelmaps.vn/gateway/mapservice/v1/media/gtrans_style.json');
    }
    mapController.onRouteSelected.add(_onRouteSelected);

    new Timer(const Duration(seconds: 8), () {
      ///print("This line will print after 8 seconds");
      //mapController.clearRoute();
      //mapController.buildRoute(wayPoints: wayPoints);

      mapController.startNavigation(
          wayPoints: wayPoints,
          options: VTMapOptions(
              mode: VTMapNavigationMode.driving,
              simulateRoute: true,
              alternatives: true,
              startIndex: 1));

      mapController.selectedRoute(1);
    });
  }

  void _onRouteSelected(int index) {
    print("_onRouteSelected at : " + index.toString());
    Fluttertoast.showToast(
        msg: "_onRouteSelected at: " + index.toString(),
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.CENTER,
        timeInSecForIosWeb: 1,
        backgroundColor: Colors.red,
        textColor: Colors.white,
        fontSize: 16.0);
  }

  @override
  Widget build(BuildContext context) {
    return new Scaffold(
        body: VTMap(
      accessToken: MapsDemo.ACCESS_TOKEN,
      // gpsControlEnable: true,
      // mapTypeControlEnable: true,
      //styleString: 'https://api.viettelmaps.vn/gateway/mapservice/v1/media/style.json',
      onMapCreated: _onMapCreated,
      onStyleLoadedCallback: _onStyleLoadedCallback,
      onCameraIdle: _onCameraIdle,
      gpsControlEnable: false,
      //myLocationTrackingMode: MyLocationTrackingMode.TrackingCompass,
      onCameraMovingStarted: _onCameraMovingStarted,
      initialCameraPosition:
          const CameraPosition(target: LatLng(16.065423, 108.188714), zoom: 14),
      onMapClick: (Point<double> point, LatLng coordinates) {
        print("-------------------------- onMapClick: " + point.toString());
      },
    ));
  }
}
